@@ -383,7 +383,9 @@ use <% $module %>::<% $moniker %>::View;
 # load plugins
 __PACKAGE__->load_plugins(
     'Web::FillInFormLite',
-    'Web::CSRFDefender',
+    'Web::CSRFDefender' => {
+        post_only => 1,
+    },
 );
 
 sub show_error {
